==> limix-legacy-0.8.7.tar.gz: limix-legacy-0.8.7/README.md <==
# Limix

[![PyPI-License](https://img.shields.io/pypi/l/limix_legacy.svg?style=flat-square)](https://pypi.python.org/pypi/limix/) [![PyPI-Version](https://img.shields.io/pypi/v/limix_legacy.svg?style=flat-square)](https://pypi.python.org/pypi/limix/) [![Anaconda-Version](https://anaconda.org/conda-forge/limix/badges/version.svg)](https://anaconda.org/conda-forge/limix) [![Anaconda-Downloads](https://anaconda.org/conda-forge/limix/badges/downloads.svg)](https://anaconda.org/conda-forge/limix)

Limix is a flexible and efficient linear mixed model library with interfaces
to Python.
Genomic analyses require flexible models that can be adapted to the needs of
the user.
Limix is smart about how particular models are fitted to save
computational cost.

LATEST: [iSet, interaction set tests for gene-context interactions, is now in Limix.](https://github.com/PMBio/limix-tutorials/tree/master/iSet)

## Install

The recommended way of installing it is via
[conda](http://conda.pydata.org/docs/index.html)

```bash
conda install -c conda-forge limix
```

An alternative way (and likely to fail) would be via pip

```
pip install limix
```

## Usage

A good starting point is our package Vignettes.
These tutorials are available from this repository:
https://github.com/PMBio/limix-tutorials.

The main package vignette can also be viewed using the ipython notebook viewer:
http://nbviewer.ipython.org/github/pmbio/limix-tutorials/blob/master/index.ipynb.

Alternatively, the source file is available in the separate Limix tutorial repository:
https://github.com/PMBio/limix-tutorials

## Problems

If you encounter any issue, please, [submit it](https://github.com/PMBio/limix/issues).

## Authors

* **Christoph Lippert** - [https://github.com/clippert](https://github.com/clippert)
* **Danilo Horta** - [https://github.com/Horta](https://github.com/Horta)
* **Franceso Paolo Casale** - [https://github.com/fpcasale](https://github.com/fpcasale)
* **Oliver Stegle** - [https://github.com/ostegle](https://github.com/ostegle)

## License

This project is licensed under the Apache License (Version 2.0, January 2004) -
see the [LICENSE](LICENSE) file for details

==> limix-legacy-0.8.9.tar.gz: limix-legacy-0.8.9/README.md <==
# Limix

[![PyPI-License](https://img.shields.io/pypi/l/limix_legacy.svg?style=flat-square)](https://pypi.python.org/pypi/limix_legacy/) [![PyPI-Version](https://img.shields.io/pypi/v/limix_legacy.svg?style=flat-square)](https://pypi.python.org/pypi/limix_legacy/) [![Anaconda-Version](https://anaconda.org/conda-forge/limix_legacy/badges/version.svg)](https://anaconda.org/conda-forge/limix_legacy) [![Anaconda-Downloads](https://anaconda.org/conda-forge/limix_legacy/badges/downloads.svg)](https://anaconda.org/conda-forge/limix_legacy)

Limix is a flexible and efficient linear mixed model library with interfaces
to Python.
Genomic analyses require flexible models that can be adapted to the needs of
the user.
Limix is smart about how particular models are fitted to save
computational cost.

LATEST: [iSet, interaction set tests for gene-context interactions, is now in Limix.](https://github.com/PMBio/limix-tutorials/tree/master/iSet)

## Install

The recommended way of installing it is via
[conda](http://conda.pydata.org/docs/index.html)

```bash
conda install -c conda-forge limix-legacy
```

An alternative way (and likely to fail) would be via pip

```
pip install limix-legacy
```

## Usage

A good starting point is our package Vignettes.
These tutorials are available from this repository:
https://github.com/PMBio/limix-tutorials.

The main package vignette can also be viewed using the ipython notebook viewer:
http://nbviewer.ipython.org/github/pmbio/limix-tutorials/blob/master/index.ipynb.

Alternatively, the source file is available in the separate Limix tutorial repository:
https://github.com/PMBio/limix-tutorials

## Problems

If you encounter any issue, please, [submit it](https://github.com/PMBio/limix/issues).

## Authors

* **Christoph Lippert** - [https://github.com/clippert](https://github.com/clippert)
* **Danilo Horta** - [https://github.com/Horta](https://github.com/Horta)
* **Franceso Paolo Casale** - [https://github.com/fpcasale](https://github.com/fpcasale)
* **Oliver Stegle** - [https://github.com/ostegle](https://github.com/ostegle)

## License

This project is licensed under the Apache License (Version 2.0, January 2004) -
see the [LICENSE](LICENSE) file for details
